Package: MethylAid
Type: Package
Title: Visual and interactive quality control of large Illumina DNA
        Methylation array data sets
Version: 1.45.0
Date: 2019-10-07
Authors@R: c(person("Maarten", "van Iterson",
        email="mviterson@gmail.com", role="cre"),
	person("Elmar", "Tobi", role="ctb"),
	person("Roderick", "Slieker", role="ctb"),
	person("Wouter", "den Hollander", role="ctb"),
	person("Rene", "Luijk", role="ctb"),
	person("Bas", "Heijmans", role="ctb"))
Author: Maarten van Iterson [aut, cre], Elmar Tobi[ctb],
        Roderick Slieker[ctb], Wouter den Hollander[ctb],
	Rene Luijk[ctb] and Bas Heijmans[ctb]
Maintainer: L.J.Sinke <L.J.Sinke@lumc.nl>
Description: A visual and interactive web application using RStudio's
    shiny package. Bad quality samples are detected using
    sample-dependent and sample-independent controls present on the
    array and user adjustable thresholds. In depth exploration of
    bad quality samples can be performed using several interactive
    diagnostic plots of the quality control probes present on the
    array. Furthermore, the impact of any batch effect provided by
    the user can be explored.
License: GPL (>= 2)
VignetteBuilder: knitr
biocViews: DNAMethylation, MethylationArray, Microarray, TwoChannel,
        QualityControl, BatchEffect, Visualization, GUI
Depends: R (>= 3.4)
Imports: Biobase, BiocParallel, BiocGenerics, ggplot2, grid, gridBase,
        grDevices, graphics, hexbin, matrixStats, minfi (>= 1.22.0),
        methods, RColorBrewer, shiny, stats, SummarizedExperiment,
        utils
Suggests: BiocStyle, knitr, MethylAidData, minfiData, minfiDataEPIC,
        RUnit
RoxygenNote: 6.0.1
git_url: https://git.bioconductor.org/packages/MethylAid
git_branch: devel
git_last_commit: 4bb83e1
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 23:31:09 UTC; biocbuild
