# Generated by roxygen2: do not edit by hand

export(summarize)
export(visualize)
exportClasses(summarizedData)
exportMethods(combine)
exportMethods(show)
import(BiocParallel)
import(RColorBrewer)
import(ggplot2)
import(methods)
import(minfi)
import(shiny)
importFrom(Biobase,AnnotatedDataFrame)
importFrom(BiocGenerics,combine)
importFrom(SummarizedExperiment,colData)
importFrom(grDevices,blues9)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,abline)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(gridBase,baseViewports)
importFrom(hexbin,grid.hexagons)
importFrom(hexbin,hexbin)
importFrom(matrixStats,colMads)
importFrom(matrixStats,colMedians)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,sd)
importFrom(utils,str)
importFrom(utils,write.csv)
