##demo version of the MethylAid App
MethylAid:::server(exampleData, thresholds = list(hm450k=list(MU = 10.50, OP = 11.75, BS = 12.75, HC = 13.25, DP = 0.95),
                                      epic=list(MU = 10, OP = 12, BS = 11.75, HC = 12.75, DP = 0.95)), background=NULL)
